require 'spec_helper'

describe Stasis::Extensions::Assets do

  let(:project_folder) { File.expand_path('../../../../fixtures/project', __FILE__) }
  let(:stasis) { Stasis.new(project_folder) }

  describe "an instance of the plugin" do
    before do
      @plugin = Stasis::Extensions::Assets.new(stasis)
    end

    it "should have an empty assets Hash" do
      expect(@plugin.assets).to eq({})
    end

    describe "#reset" do
      it "should empty the assets Hash" do
        @plugin.assets['test'] = 'test'
        @plugin.reset
        expect(@plugin.assets).to eq({})
      end
    end

    describe "#before_all" do
      before do
        @plugin.before_all
      end

      it "should fingerprint css" do
        expect(@plugin.assets).to include('css/simple.css')
        expect(@plugin.assets['css/simple.css']).to eq("css/simple-#{digest_for('css/simple.css')}.css")
      end

      it "should fingerprint scss" do
        expect(@plugin.assets).to include('css/compiled.css')
        expect(@plugin.assets['css/compiled.css']).to eq("css/compiled-#{digest_for('css/compiled.css.scss')}.css")
      end

      it "should fingerprint images" do
        expect(@plugin.assets).to include('images/stasis.png')
        expect(@plugin.assets['images/stasis.png']).to eq("images/stasis-#{digest_for('images/stasis.png')}.png")
      end

      it "should fingerprint js" do
        expect(@plugin.assets).to include('js/simple.js')
        expect(@plugin.assets['js/simple.js']).to eq("js/simple-#{digest_for('js/simple.js')}.js")
      end

      it "should fingerprint erb" do
        expect(@plugin.assets).to include('js/compiled.js')
        expect(@plugin.assets['js/compiled.js']).to eq("js/compiled-#{digest_for('js/compiled.js.erb')}.js")
      end
    end
  end

  describe "when rendered" do
    describe "the rendered assets" do
      before do
        stasis_render
      end

      it "should include css" do
        expect(file_for("public/css/simple.css")).to exist
      end

      it "should include scss" do
        expect(file_for("public/css/compiled.css")).to exist
      end

      it "should include images" do
        expect(file_for("public/images/stasis.png")).to exist
      end

      it "should include js" do
        expect(file_for("public/js/simple.js")).to exist
      end

      it "should include erb" do
        expect(file_for("public/js/compiled.js")).to exist
      end

      it "should include fingerprinted css" do
        expect(file_for("public/css/simple-#{digest_for('css/simple.css')}.css")).to exist
      end

      it "should include fingerprinted scss" do
        expect(file_for("public/css/compiled-#{digest_for('css/compiled.css.scss')}.css")).to exist
      end

      it "should include fingerprinted images" do
        expect(file_for("public/images/stasis-#{digest_for('images/stasis.png')}.png")).to exist
      end

      it "should include fingerprinted js" do
        expect(file_for("public/js/simple-#{digest_for('js/simple.js')}.js")).to exist
      end

      it "should include fingerprinted erb" do
        expect(file_for("public/js/compiled-#{digest_for('js/compiled.js.erb')}.js")).to exist
      end
    end

    describe "#asset_path" do
      it "should render the asset path" do
        stasis_render 'assets/asset_path.haml'
        expect(contents_of('public/assets/asset_path')).to eq("/images/stasis-#{digest_for('images/stasis.png')}.png")
      end
    end

    describe "#asset_url" do
      it "should render the asset url" do
        stasis_render 'assets/asset_url.haml'
        expect(contents_of('public/assets/asset_url')).to eq("http://example.com/images/stasis-#{digest_for('images/stasis.png')}.png")
      end
    end
  end
end
